@@ -1,23 +1,29 @@
-/*
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 
- * USA
- */
+/*******************************************************************************
+ cmodel_permutation.h
 
-#include <colorspace_tables.h>
-#include <colorspace_macros.h>
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
 
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/
+
+#include "colorspace_tables.h"
+#include "colorspace_macros.h"
 #include <quicktime/colormodels.h>
 #include <inttypes.h>
 
@@ -568,6 +574,21 @@ static inline void transfer_RGB161616_to_YUV420P_YUV422P(unsigned char *output_y
 	output_v[output_column / 2] = v;
 }
 
+static inline void transfer_RGB161616_to_YUV422P16(uint16_t *output_y, 
+	uint16_t *output_u, 
+	uint16_t *output_v, 
+	uint16_t *input,
+	int output_column)
+{
+	int y, u, v;
+
+	RGB_48_TO_YUV_16(input[0], input[1], input[2], y, u, v);
+
+	output_y[output_column] = y;
+	output_u[output_column / 2] = u;
+	output_v[output_column / 2] = v;
+}
+
 static inline void transfer_RGB161616_to_YUV444P(unsigned char *output_y, 
 	unsigned char *output_u, 
 	unsigned char *output_v, 
@@ -586,6 +607,21 @@ static inline void transfer_RGB161616_to_YUV444P(unsigned char *output_y,
 	output_v[output_column] = v;
 }
 
+static inline void transfer_RGB161616_to_YUV444P16(uint16_t *output_y, 
+	uint16_t *output_u, 
+	uint16_t *output_v, 
+	uint16_t *input,
+	int output_column)
+{
+	int y, u, v;
+
+	RGB_48_TO_YUV_16(input[0], input[1], input[2], y, u, v);
+
+	output_y[output_column] = y;
+	output_u[output_column] = u;
+	output_v[output_column] = v;
+}
+
 
 // ****************************** RGBA16161616 -> *****************************
 
@@ -1225,6 +1261,16 @@ static inline void transfer_YUV422P16_to_RGB888(unsigned char *(*output),
 	(*output) += 3;
 }
 
+static inline void transfer_YUV422P16_to_RGB161616(uint16_t *(*output), 
+	uint16_t *input_y,
+	uint16_t *input_u,
+	uint16_t *input_v)
+{
+        int i_tmp;
+	YUV_16_TO_RGB_48(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+	(*output) += 3;
+}
+
 static inline void transfer_YUV422P16_to_YUV420P16(uint16_t *input_y,
                                                    uint16_t *input_u,
                                                    uint16_t *input_v,
@@ -1263,6 +1309,16 @@ static inline void transfer_YUV444P16_to_RGB888(unsigned char *(*output),
 	(*output) += 3;
 }
 
+static inline void transfer_YUV444P16_to_RGB161616(uint16_t *(*output), 
+	uint16_t *input_y,
+	uint16_t *input_u,
+	uint16_t *input_v)
+{
+        int i_tmp;
+	YUV_16_TO_RGB_48(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+	(*output) += 3;
+}
+
 static inline void transfer_YUV444P16_to_YUV444P16(uint16_t *input_y,
 	uint16_t *input_u,
 	uint16_t *input_v,
@@ -1326,7 +1382,7 @@ static inline void transfer_YUVJ444P_to_RGB888(unsigned char *(*output),
 	unsigned char *input_v)
 {
         int i_tmp;
-	YUV_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+	YUVJ_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
 	(*output) += 3;
 }
 
@@ -1338,7 +1394,7 @@ static inline void transfer_YUVJ422P_to_RGB888(unsigned char *(*output),
 	unsigned char *input_v)
 {
         int i_tmp;
-	YUV_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+	YUVJ_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
 	(*output) += 3;
 }
 
@@ -1384,7 +1440,7 @@ static inline void transfer_YUVJ420P_to_RGB888(unsigned char *(*output),
 	unsigned char *input_v)
 {
         int i_tmp;
-	YUV_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
+	YUVJ_8_TO_RGB_24(*input_y, *input_u, *input_v, (*output)[0], (*output)[1], (*output)[2])
 	(*output) += 3;
 }
 
@@ -1685,6 +1741,16 @@ static inline void transfer_YUV422_to_YUVJ422P(unsigned char *output_y,
 		for(j = 0; j < out_w; j++) \
 		{
 
+#define TRANSFER_YUV422P16_OUT_HEAD_16   \
+	for(i = 0; i < out_h; i++) \
+	{ \
+                unsigned char *input_row = input_rows[row_table[i]]; \
+		uint16_t *output_y = (uint16_t *)(output_rows[0] + i * out_rowspan); \
+		uint16_t *output_u = (uint16_t *)(output_rows[1] + i * out_rowspan_uv); \
+		uint16_t *output_v = (uint16_t *)(output_rows[2] + i * out_rowspan_uv); \
+                for(j = 0; j < out_w; j++)                        \
+		{
+
 #define TRANSFER_YUV411P_OUT_HEAD \
 	for(i = 0; i < out_h; i++) \
 	{ \
@@ -1706,6 +1772,16 @@ static inline void transfer_YUV422_to_YUVJ422P(unsigned char *output_y,
 		for(j = 0; j < out_w; j++) \
 		{
 
+#define TRANSFER_YUV444P16_OUT_HEAD_16   \
+	for(i = 0; i < out_h; i++) \
+	{ \
+                unsigned char *input_row = input_rows[row_table[i]]; \
+		uint16_t *output_y = (uint16_t *)(output_rows[0] + i * out_rowspan); \
+		uint16_t *output_u = (uint16_t *)(output_rows[1] + i * out_rowspan_uv); \
+		uint16_t *output_v = (uint16_t *)(output_rows[2] + i * out_rowspan_uv); \
+                for(j = 0; j < out_w; j++)                        \
+		{
+
 #define TRANSFER_YUV420P_IN_HEAD \
 	for(i = 0; i < out_h; i++) \
 	{ \
@@ -1767,6 +1843,16 @@ static inline void transfer_YUV422_to_YUVJ422P(unsigned char *output_y,
 		for(j = 0; j < out_w; j++) \
 		{
 
+#define TRANSFER_YUV422P16_IN_HEAD_16   \
+	for(i = 0; i < out_h; i++) \
+	{ \
+                uint16_t *output_row = (uint16_t *)(output_rows[i]); \
+		uint16_t * input_y = (uint16_t *)(input_rows[0] + row_table[i] * in_rowspan); \
+		uint16_t * input_u = (uint16_t *)(input_rows[1] + row_table[i] * in_rowspan_uv); \
+		uint16_t * input_v = (uint16_t *)(input_rows[2] + row_table[i] * in_rowspan_uv); \
+                for(j = 0; j < out_w; j++)                        \
+		{
+
 #define TRANSFER_YUV444P_IN_HEAD \
 	for(i = 0; i < out_h; i++) \
 	{ \
@@ -1798,6 +1884,15 @@ static inline void transfer_YUV422_to_YUVJ422P(unsigned char *output_y,
 		for(j = 0; j < out_w; j++) \
 		{
 
+#define TRANSFER_YUV444P16_IN_HEAD_16 \
+	for(i = 0; i < out_h; i++) \
+	{ \
+                uint16_t *output_row = (uint16_t *)(output_rows[i]); \
+		uint16_t *input_y = (uint16_t *)(input_rows[0] + row_table[i] * in_rowspan); \
+		uint16_t *input_u = (uint16_t *)(input_rows[1] + row_table[i] * in_rowspan_uv); \
+		uint16_t *input_v = (uint16_t *)(input_rows[2] + row_table[i] * in_rowspan_uv); \
+		for(j = 0; j < out_w; j++) \
+		{
 
 #define TRANSFER_YUV422_IN_HEAD \
 	for(i = 0; i < out_h; i++) \
