@@ -32,8 +32,12 @@
 #ifndef _LQT_CODEC_INFO_H_
 #define _LQT_CODEC_INFO_H_
 
+#pragma GCC visibility push(default)
+
 #include <inttypes.h>
 
+
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -154,6 +158,12 @@ typedef enum
     LQT_DIRECTION_BOTH
   } lqt_codec_direction;
 
+/** \ingroup codec_registry
+    \brief compatibility flags contain this for obsolete/unmaintained codecs
+*/
+
+#define LQT_CODEC_OBSOLETE (1<<24)
+  
 /** \ingroup codec_registry
     \brief Structure describing a codec
 */
@@ -191,8 +201,11 @@ typedef struct lqt_codec_info_s
   
   uint32_t file_time;        /*!< File modification time of the module */
 
-  char * gettext_domain;     /*!< First argument to bindtextdomain(). Must be set only for externally packaged codecs */
-  char * gettext_directory;  /*!< Second argument to bindtextdomain(). Must be set only for externally packaged codecs */
+  char * gettext_domain;     /*!< First argument to bindtextdomain()  */
+  char * gettext_directory;  /*!< Second argument to bindtextdomain() */
+
+  int num_encoding_colormodels; /*!< Number of supported encoding colormodels (since 1.1.2) */
+  int * encoding_colormodels;  /*!< Supported encoding colormodels (since 1.1.2) */
   
   struct lqt_codec_info_s * next;   /*!< For chaining (used internally only) */
   } lqt_codec_info_t;
@@ -463,5 +476,6 @@ void lqt_dump_codec_info(const lqt_codec_info_t * info);
 }
 #endif /* __cplusplus */
 
+#pragma GCC visibility pop
 
 #endif /* _LQT_CODEC_INFO_H_ */
