@@ -158,21 +158,21 @@ typedef struct
 
 typedef struct
 {
-    int version;
-    int revision;
-    long imagingMode;
-    long imagingValidFlags;
-    long correction;
-    long quality;
-    long directdraw;
-    long imagingProperties[5];
-    long reserved1;
-    long reserved2;
+	uint16_t version;
+	uint16_t revision;
+	uint32_t imagingMode;
+	uint32_t imagingValidFlags;
+	uint32_t correction;
+	uint32_t quality;
+	uint32_t directdraw;
+	uint32_t imagingProperties[6];
+	uint32_t reserved1;
+	uint32_t reserved2;
 } quicktime_impn_t;
 
 typedef struct
 {
-    quicktime_impn_t impn;
+	quicktime_impn_t impn;
 } quicktime_imgp_t;
 
 typedef struct
@@ -423,6 +423,25 @@ typedef struct
   quicktime_ftab_t ftab;
   } quicktime_stsd_tx3g_t;
 
+/* Sample description for timecode tracks */
+
+typedef struct
+  {
+  uint32_t reserved2;
+  uint32_t flags;
+  uint32_t timescale;
+  uint32_t frameduration;
+  uint8_t numframes;
+
+// http://developer.apple.com/documentation/QuickTime/QTFF/QTFFChap3/chapter_4_section_4.html#//apple_ref/doc/uid/TP40000939-CH205-BBCGABGG
+  //  uint8_t reserved3[3];
+
+  // Real life
+  uint8_t reserved3;
+  
+  char * name;
+  } quicktime_stsd_tmcd_t;
+
 typedef struct
 {
 	char format[4];
@@ -446,6 +465,7 @@ typedef struct
 	char compressor_name[32];
 	int depth;
 	int ctab_id;
+        int has_ctab;
 	quicktime_ctab_t ctab;
 
         quicktime_pasp_t pasp;
@@ -507,6 +527,8 @@ typedef struct
 /* Quicktime tx3g */
         quicktime_stsd_tx3g_t tx3g;
 
+        quicktime_stsd_tmcd_t tmcd;
+
 } quicktime_stsd_table_t;
 
 
@@ -521,10 +543,10 @@ typedef struct
 
 /* time to sample */
 typedef struct
-{
-	long sample_count;
-	long sample_duration;
-} quicktime_stts_table_t;
+  {
+  uint32_t sample_count;
+  int32_t sample_duration;
+  } quicktime_stts_table_t;
 
 typedef struct
 {
@@ -539,10 +561,10 @@ typedef struct
 /* Composition time to sample */
 
 typedef struct
-{
-	long sample_count;
-	long sample_duration;
-} quicktime_ctts_table_t;
+  {
+  uint32_t sample_count;
+  int32_t sample_duration;
+  } quicktime_ctts_table_t;
 
 typedef struct
 {
@@ -620,6 +642,7 @@ typedef struct
 	
 	long entries_allocated;    /* used by the library for allocating a table */
 	quicktime_stco_table_t *table;
+        int co64;
 } quicktime_stco_t;
 
 
@@ -721,6 +744,22 @@ typedef struct
   uint32_t unk[9];
   } quicktime_gmhd_text_t;
 
+typedef struct
+  {
+  int version;
+  long flags;
+  int font;
+  int face;
+  int size;
+  int txtcolor[3];
+  int bgcolor[3];
+  char fontname[256];
+  } quicktime_tcmi_t;
+
+typedef struct
+  {
+  quicktime_tcmi_t tcmi;
+  } quicktime_tmcd_t;
 
 /* Base (generic) media header */
 
@@ -730,6 +769,10 @@ typedef struct
 
   int has_gmhd_text;
   quicktime_gmhd_text_t gmhd_text;
+  
+  int has_tmcd;
+  quicktime_tmcd_t tmcd;
+  
   } quicktime_gmhd_t;
 
 typedef struct
@@ -763,6 +806,7 @@ typedef struct
 	int is_qtvr;
 	int is_object;
         int is_text;
+        int is_timecode;
 	quicktime_vmhd_t vmhd;
 	quicktime_smhd_t smhd;
 	quicktime_gmhd_t gmhd;
@@ -917,6 +961,8 @@ typedef struct
 	/* player controls */
 	char ctyp[4];
 	quicktime_navg_t navg;
+	quicktime_hdlr_t hdlr;
+        int has_hdlr;
 } quicktime_udta_t;
 
 
@@ -927,6 +973,7 @@ typedef struct
 	quicktime_mvhd_t mvhd;
 	quicktime_trak_t *trak[MAXTRACKS];
 	quicktime_udta_t udta;
+        int has_ctab;
 	quicktime_ctab_t ctab;
         int has_iods;
         quicktime_iods_t iods;
@@ -1262,7 +1309,7 @@ typedef struct
         /* number of audio channels in the track */
         lqt_channel_t * channel_setup;
         int64_t current_position;   /* current sample in output file */
-	int64_t current_chunk;      /* current chunk in output file */
+	int64_t cur_chunk;      /* current chunk in output file */
 
         /* Last position if set by the codec. If last position and current position
            differ, the codec knows, that a seek happened since the last decode call */
@@ -1296,36 +1343,63 @@ typedef struct
 } quicktime_audio_map_t;
 
 typedef struct
-{
-	quicktime_trak_t *track;
-	long current_position;   /* current frame in output file */
-	long current_chunk;      /* current chunk in output file */
+  {
+  quicktime_trak_t *track;
+  quicktime_trak_t *timecode_track;
+  long current_position;   /* current frame in output file */
+  long cur_chunk;      /* current chunk in output file */
 
-	void *codec;
-/* Timestamp of the NEXT frame decoded. Unit is the timescale of the track */
-/* For Encoding: Timestamp of the LAST encoded frame */
-        int64_t timestamp;
+  void *codec;
+  /* Timestamp of the NEXT frame decoded. Unit is the timescale of the track */
+  /* For Encoding: Timestamp of the LAST encoded frame */
+  int64_t timestamp;
+  
+  int64_t stts_index;
+  int64_t stts_count;
+  int stream_cmodel;  /* Colormodel, which is read/written natively by the codec  */
+  int stream_row_span, stream_row_span_uv;
 
-/* For codecs with B-frames: Timestamp of the just written frame */
-        int has_b_frames; /* Probably needed for encoding only */
-        int64_t coded_timestamp; /* Set by the codec during encoding */
+  int io_cmodel;      /* Colormodel, which is used by the encode/decode functions */
+  int io_row_span, io_row_span_uv;
 
-        int64_t stts_index;
-        int64_t stts_count;
-        int stream_cmodel;  /* Colormodel, which is read/written natively by the codec  */
-        int stream_row_span, stream_row_span_uv;
+  /* This is used by the core to do implicit colorspace conversion and scaling (NOT recommended!!) */
+  uint8_t ** temp_frame;
 
-        int io_cmodel;      /* Colormodel, which is used by the encode/decode functions */
-        int io_row_span, io_row_span_uv;
+  lqt_chroma_placement_t chroma_placement;
+  lqt_interlace_mode_t interlace_mode;
 
-        /* This is used by the core to do implicit colorspace conversion and scaling (NOT recommended!!) */
-        uint8_t ** temp_frame;
+  int compatibility_flags; /* Taken from codec info */
 
-        lqt_chroma_placement_t chroma_placement;
-        lqt_interlace_mode_t interlace_mode;
+  // Timecode stuff
+  uint32_t encode_timecode;
+  int has_encode_timecode;
+  long cur_timecode_chunk;      /* current chunk in output file */
 
-        int compatibility_flags; /* Taken from codec info */
+  /* Timestamp of the last encoded timecode */
+  int64_t timecode_timestamp;
 
+  /* For decoding, *all* timecodes are read here.
+   * For encoding, this contains a small buffer such that we don't
+   start a new chunk for each timecode. */
+  int num_timecodes;
+  uint32_t * timecodes;
+  int timecodes_written;
+
+  /* Reordering table: We build this table during encoding and
+     generate the stts and ctts atoms at the end */
+
+  int * picture_numbers;
+  int picture_numbers_alloc;
+
+  int64_t * timestamps;
+  int timestamps_alloc;
+
+  int64_t duration;
+
+  /* For encoding */
+  quicktime_atom_t chunk_atom;
+  int keyframe;
+  
   } quicktime_video_map_t;
 
 /* Text track */
@@ -1342,7 +1416,7 @@ typedef struct
   int text_buffer_alloc;
 
   int initialized; /* For encoding only */
-  int64_t current_chunk;
+  int64_t cur_chunk;
   
   } quicktime_text_map_t;
 
@@ -1552,8 +1626,8 @@ typedef struct
                             int track);
 	int (*set_parameter)(quicktime_t *file, 
 		int track, 
-		char *key, 
-		void *value);
+		const char *key, 
+		const void *value);
         /* Set the encoding pass */
         int (*set_pass)(quicktime_t *file, 
 		int track, int pass, int total_passes,
