@@ -1,16 +1,42 @@
-#include "funcprotos.h"
-#include "ima4.h"
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ ima4.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 #define LQT_LIBQUICKTIME
 #include <quicktime/lqt_codecapi.h>
-
+#include <stdlib.h>
 #include <string.h>
+#include "audiocodec.h"
+
+#define LOG_DOMAIN "ima4"
 
 /* Known by divine revelation */
 
 #define BLOCK_SIZE 0x22
 #define SAMPLES_PER_BLOCK 0x40
 
+
 typedef struct
 {
 /* Starting information for all channels during encoding. */
@@ -263,7 +289,7 @@ static int decode(quicktime_t *file, void * _output, long samples, int track)
           /* Read first chunk */
           
           codec->chunk_buffer_size =
-            lqt_read_audio_chunk(file, track, file->atracks[track].current_chunk,
+            lqt_read_audio_chunk(file, track, file->atracks[track].cur_chunk,
                                  &(codec->chunk_buffer),
                                  &(codec->chunk_buffer_alloc), &(codec->chunk_samples));
           
@@ -281,13 +307,13 @@ static int decode(quicktime_t *file, void * _output, long samples, int track)
 
           /* Read the chunk */
 
-          if(file->atracks[track].current_chunk != chunk)
+          if(file->atracks[track].cur_chunk != chunk)
             //          if(1)
             {
-            file->atracks[track].current_chunk = chunk;
+            file->atracks[track].cur_chunk = chunk;
 
             codec->chunk_buffer_size =
-              lqt_read_audio_chunk(file, track, file->atracks[track].current_chunk,
+              lqt_read_audio_chunk(file, track, file->atracks[track].cur_chunk,
                                    &(codec->chunk_buffer),
                                    &(codec->chunk_buffer_alloc), &(codec->chunk_samples));
             if(codec->chunk_buffer_size <= 0)
@@ -300,16 +326,10 @@ static int decode(quicktime_t *file, void * _output, long samples, int track)
             codec->chunk_buffer_ptr = codec->chunk_buffer;
             }
           
-#if 0          
-          fprintf(stderr, "Seeking done, pos: %lld, chunk_sample: %lld, chunk: %lld\n",
-                  file->atracks[track].current_position,
-                  chunk_sample,
-                  file->atracks[track].current_chunk);
-#endif    
           samples_to_skip = file->atracks[track].current_position - chunk_sample;
           if(samples_to_skip < 0)
             {
-            fprintf(stderr, "ima4: Cannot skip backwards\n");
+            lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "Cannot skip backwards");
             samples_to_skip = 0;
             }
           
@@ -350,10 +370,10 @@ static int decode(quicktime_t *file, void * _output, long samples, int track)
             
             if(!codec->chunk_buffer_size)
               {
-              file->atracks[track].current_chunk++;
+              file->atracks[track].cur_chunk++;
 
               codec->chunk_buffer_size =
-                lqt_read_audio_chunk(file, track, file->atracks[track].current_chunk,
+                lqt_read_audio_chunk(file, track, file->atracks[track].cur_chunk,
                                      &(codec->chunk_buffer),
                                      &(codec->chunk_buffer_alloc), &(codec->chunk_samples));
               
@@ -414,7 +434,6 @@ static int encode(quicktime_t *file, void *_input, long samples, int track)
   quicktime_atom_t chunk_atom;
   int samples_encoded, total_samples_copied, samples_copied, frames_encoded, old_buffer_size;
 
-  //  fprintf(stderr, "Encode %d (%d)\n", samples, codec->sample_buffer_size);
   
   /* Get output size */
   chunk_bytes = ima4_samples_to_bytes(samples + codec->sample_buffer_size, track_map->channels);
@@ -468,7 +487,6 @@ static int encode(quicktime_t *file, void *_input, long samples, int track)
 
     if(codec->sample_buffer_size == SAMPLES_PER_BLOCK)
       {
-      //      fprintf(stderr, "Encode block...");
       for(j = 0; j < track_map->channels; j++)
         {
         ima4_encode_block(track_map, output_ptr, codec->sample_buffer + j,
@@ -478,7 +496,6 @@ static int encode(quicktime_t *file, void *_input, long samples, int track)
       samples_encoded += SAMPLES_PER_BLOCK;
       frames_encoded ++;
       codec->sample_buffer_size = 0;
-      //      fprintf(stderr, "done\n");
       }
     else
       {
@@ -486,11 +503,9 @@ static int encode(quicktime_t *file, void *_input, long samples, int track)
       }
     }
   
-  //  fprintf(stderr, "Encoded %d frames\n", frames_encoded);
   
   /* Write to disk */
         
-  /*printf("quicktime_encode_ima4 1 %ld\n", chunk_samples); */
   /* The block division may result in 0 samples getting encoded. */
   /* Don't write 0 samples. */
   if(samples_encoded)
@@ -499,7 +514,7 @@ static int encode(quicktime_t *file, void *_input, long samples, int track)
     result = quicktime_write_data(file, codec->chunk_buffer, chunk_bytes);
     quicktime_write_chunk_footer(file, 
                                  trak,
-                                 track_map->current_chunk,
+                                 track_map->cur_chunk,
                                  &chunk_atom, 
                                  samples_encoded);
 
@@ -508,9 +523,8 @@ static int encode(quicktime_t *file, void *_input, long samples, int track)
     else 
       result = 1; /* defeat fwrite's return */
 
-    track_map->current_chunk++;
+    track_map->cur_chunk++;
     }
-  //  fprintf(stderr, "Keeping %d samples\n", codec->sample_buffer_size);
   return result;
   }
 
@@ -526,7 +540,6 @@ static int flush(quicktime_t *file, int track)
   int i;
   unsigned char *output_ptr;
   
-  //  fprintf(stderr, "quicktime_flush_ima4 %d\n", codec->sample_buffer_size);
   if(codec->sample_buffer_size)
     {
     /* Zero out enough to get a block */
@@ -545,10 +558,10 @@ static int flush(quicktime_t *file, int track)
     result = quicktime_write_data(file, codec->chunk_buffer, (int)(output_ptr - codec->chunk_buffer));
     quicktime_write_chunk_footer(file,
                                  trak,
-                                 track_map->current_chunk,
+                                 track_map->cur_chunk,
                                  &chunk_atom, 
                                  codec->sample_buffer_size);
-    track_map->current_chunk++;
+    track_map->cur_chunk++;
     return 1;
     }
   return 0;
