@@ -742,11 +742,12 @@ static int read_audio_chunk(quicktime_t * file, int track,
                             long chunk,
                             uint8_t ** buffer, int * buffer_alloc)
   {
-  int bytes, samples, bytes_from_samples;
+  int bytes, samples = 0, bytes_from_samples;
   quicktime_audio_map_t *track_map = &(file->atracks[track]);
   quicktime_pcm_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
-
+  
   bytes = lqt_read_audio_chunk(file, track, chunk, buffer, buffer_alloc, &samples);
+
   bytes_from_samples = samples * codec->block_align;
   if(bytes > bytes_from_samples)
     return bytes_from_samples;
@@ -772,7 +773,7 @@ static int decode_pcm(quicktime_t *file, void * _output, long samples, int track
     /* Read the first audio chunk */
 
     codec->chunk_buffer_size = read_audio_chunk(file,
-                                                track, file->atracks[track].current_chunk,
+                                                track, file->atracks[track].cur_chunk,
                                                 &(codec->chunk_buffer),
                                                 &(codec->chunk_buffer_alloc));
     if(codec->chunk_buffer_size <= 0)
@@ -798,11 +799,11 @@ static int decode_pcm(quicktime_t *file, void * _output, long samples, int track
 
     /* Read the chunk */
     
-    if(file->atracks[track].current_chunk != chunk)
+    if(file->atracks[track].cur_chunk != chunk)
       {
-      file->atracks[track].current_chunk = chunk;
+      file->atracks[track].cur_chunk = chunk;
       codec->chunk_buffer_size = read_audio_chunk(file,
-                                                  track, file->atracks[track].current_chunk,
+                                                  track, file->atracks[track].cur_chunk,
                                                   &(codec->chunk_buffer),
                                                   &(codec->chunk_buffer_alloc));
       if(codec->chunk_buffer_size <= 0)
@@ -835,9 +836,9 @@ static int decode_pcm(quicktime_t *file, void * _output, long samples, int track
     /* Get new chunk if necessary */
     if(codec->chunk_buffer_ptr - codec->chunk_buffer >= codec->chunk_buffer_size)
       {
-      file->atracks[track].current_chunk++;
+      file->atracks[track].cur_chunk++;
       codec->chunk_buffer_size = read_audio_chunk(file,
-                                                  track, file->atracks[track].current_chunk,
+                                                  track, file->atracks[track].cur_chunk,
                                                   &(codec->chunk_buffer),
                                                   &(codec->chunk_buffer_alloc));
       if(codec->chunk_buffer_size <= 0)
@@ -854,6 +855,10 @@ static int decode_pcm(quicktime_t *file, void * _output, long samples, int track
     
     if(samples_to_decode > samples_in_chunk)
       samples_to_decode = samples_in_chunk;
+
+    if(!samples_to_decode) // EOF
+      break;
+
     codec->decode(codec, samples_to_decode * track_map->channels, &output);
     samples_decoded += samples_to_decode;
     }
@@ -915,8 +920,8 @@ static int encode_pcm(quicktime_t *file, void * input, long samples, int track)
 
   quicktime_write_chunk_header(file, trak, &chunk_atom);
   result = quicktime_write_data(file, codec->chunk_buffer, samples * codec->block_align);
-  quicktime_write_chunk_footer(file, trak, track_map->current_chunk, &chunk_atom, samples);
-  file->atracks[track].current_chunk++;		
+  quicktime_write_chunk_footer(file, trak, track_map->cur_chunk, &chunk_atom, samples);
+  file->atracks[track].cur_chunk++;		
   
   /* defeat fwrite's return */
   if(result) 
