@@ -180,13 +180,14 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 
 
 		dv_encode_full_frame( codec->dv_encoder,
-							  input_rows, encode_dv_colormodel, codec->data );
+                                      input_rows, encode_dv_colormodel, codec->data );
 
+                lqt_write_frame_header(file, track, vtrack->current_position,
+                                       -1, 0);
                 
-                quicktime_write_chunk_header(file, trak, &chunk_atom);
                 result = !quicktime_write_data(file, codec->data, data_length);
-                quicktime_write_chunk_footer(file, trak, vtrack->current_chunk, &chunk_atom, 1);
-                file->vtracks[track].current_chunk++;
+
+                lqt_write_frame_footer(file, track);
 	}
 
 	return result;
