@@ -28,6 +28,7 @@
 #include <faac.h>
 #include <string.h>
 #include <stdlib.h>
+#include "qtfaac.h"
 
 #define LOG_DOMAIN "faac"
 
@@ -45,6 +46,8 @@ typedef struct
 
   int chunk_started;
   quicktime_atom_t chunk_atom;
+
+  int encoder_delay;
   
   /* Configuration stuff */
   int bitrate;
@@ -66,7 +69,7 @@ static int delete_codec(quicktime_audio_map_t *track_map)
   }
 
 static int encode_frame(quicktime_t *file, 
-                        int track)
+                        int track, int num_samples)
   {
   int imax, i;
   int bytes_encoded;
@@ -77,16 +80,23 @@ static int encode_frame(quicktime_t *file,
   /* Normalize input to 16 bit int */
 
   imax = codec->sample_buffer_size * track_map->channels;
-
+  
+  if(!num_samples && (codec->encoder_delay < 0))
+    return 0;
+  
   for(i = 0; i < imax; i++)
     {
     codec->sample_buffer[i] *= 32767.0;
     }
   
+  codec->encoder_delay += num_samples;
+  
   /* Encode this frame */
   bytes_encoded = faacEncEncode(codec->enc,
                                 (int32_t*)codec->sample_buffer,
-                                codec->sample_buffer_size * track_map->channels,
+                                codec->sample_buffer_size ?
+                                codec->samples_per_frame *
+                                track_map->channels : 0,
                                 codec->chunk_buffer,
                                 codec->chunk_buffer_size);
 
@@ -96,8 +106,9 @@ static int encode_frame(quicktime_t *file,
     {
     return 0;
     }
-  
 
+  codec->encoder_delay -= codec->samples_per_frame;
+  
   /* Write these data */
 
   if(!codec->chunk_started)
@@ -110,8 +121,13 @@ static int encode_frame(quicktime_t *file,
   lqt_start_audio_vbr_frame(file, track);
   result = !quicktime_write_data(file, codec->chunk_buffer,
                                  bytes_encoded);
-  
-  lqt_finish_audio_vbr_frame(file, track, codec->samples_per_frame);
+  if(codec->encoder_delay < 0)
+    {
+    lqt_finish_audio_vbr_frame(file, track, codec->samples_per_frame +
+                               codec->encoder_delay);
+    }
+  else
+    lqt_finish_audio_vbr_frame(file, track, codec->samples_per_frame);
   
   return 1;
   }
@@ -196,14 +212,20 @@ static int encode(quicktime_t *file,
     mp4a_atom[3] = 0x00;
     
     quicktime_wave_set_user_atom(trak, "mp4a", mp4a_atom, 4);
-
+#if 0
     quicktime_set_stsd_audio_v2(&(trak->mdia.minf.stbl.stsd.table[0]),
                                 0x00000002, /* formatSpecificFlags */
                                 0, /* constBytesPerAudioPacket */
                                 codec->samples_per_frame /* constLPCMFramesPerAudioPacket */);
-
-    /* Will be switched back to 16 for mp4 by quicktime_write_stsd_audio */
-    trak->mdia.minf.stbl.stsd.table[0].sample_size = 0; 
+#else
+    quicktime_set_stsd_audio_v1(&(trak->mdia.minf.stbl.stsd.table[0]),
+                                1024, // uint32_t samples_per_packet,
+                                768, // uint32_t bytes_per_packet,
+                                1536, // uint32_t bytes_per_frame,
+                                0 // uint32_t bytes_per_sample
+                                );
+#endif
+    trak->mdia.minf.stbl.stsd.table[0].sample_size = 16;
     
     esds->version         = 0;
     esds->flags           = 0;
@@ -259,7 +281,7 @@ static int encode(quicktime_t *file,
     
     /* Encode one frame, possibly starting a new audio chunk */
     if(codec->sample_buffer_size == codec->samples_per_frame)
-      encode_frame(file, track);
+      encode_frame(file, track, codec->samples_per_frame);
     
     }
 
@@ -268,10 +290,10 @@ static int encode(quicktime_t *file,
     {
     quicktime_write_chunk_footer(file,
                                  trak,
-                                 track_map->current_chunk,
+                                 track_map->cur_chunk,
                                  &codec->chunk_atom,
                                  track_map->vbr_num_frames);
-    track_map->current_chunk++;
+    track_map->cur_chunk++;
     codec->chunk_started = 0;
     }
   return 0;
@@ -321,10 +343,10 @@ static int flush(quicktime_t *file, int track)
       {
       codec->sample_buffer[i] = 0.0;
       }
-    codec->sample_buffer_size = codec->samples_per_frame;
+    //    codec->sample_buffer_size = codec->samples_per_frame;
     }
 
-  while(encode_frame(file, track))
+  while(encode_frame(file, track, codec->sample_buffer_size))
     ;
   
   /* Finalize audio chunk */
@@ -332,10 +354,10 @@ static int flush(quicktime_t *file, int track)
     {
     quicktime_write_chunk_footer(file,
                                  trak,
-                                 track_map->current_chunk,
+                                 track_map->cur_chunk,
                                  &codec->chunk_atom,
                                  track_map->vbr_num_frames);
-    track_map->current_chunk++;
+    track_map->cur_chunk++;
     codec->chunk_started = 0;
     return 1;
     }
