@@ -24,8 +24,7 @@
 
 #include "lqt_private.h"
 #include <quicktime/lqt_codecapi.h>
-
-extern void quicktime_init_codec_faad2(quicktime_audio_map_t *atrack);
+#include "faad2.h"
 
 static char * fourccs_faad2[]     = { "mp4a", (char*)0 };
 
@@ -44,9 +43,9 @@ static lqt_codec_info_static_t codec_info_faad2 =
 
 /* These are called from the plugin loader */
 
-extern int get_num_codecs() { return 1; }
+LQT_EXTERN int get_num_codecs() { return 1; }
 
-extern lqt_codec_info_static_t * get_codec_info(int index)
+LQT_EXTERN lqt_codec_info_static_t * get_codec_info(int index)
   {
   switch(index)
     {
@@ -61,7 +60,7 @@ extern lqt_codec_info_static_t * get_codec_info(int index)
  *   Return the actual codec constructor
  */
 
-extern lqt_init_audio_codec_func_t get_audio_codec(int index)
+LQT_EXTERN lqt_init_audio_codec_func_t get_audio_codec(int index)
   {
   return quicktime_init_codec_faad2;
   }
