@@ -463,7 +463,10 @@ static int lqt_ffmpeg_decode_video(quicktime_t *file, unsigned char **row_pointe
     
     //    codec->avctx->get_buffer = avcodec_default_get_buffer;
     //    codec->avctx->release_buffer = avcodec_default_release_buffer;
-    
+
+    codec->avctx->codec_id = codec->decoder->id;
+    codec->avctx->codec_type = codec->decoder->type;
+ 
     if(avcodec_open(codec->avctx, codec->decoder) != 0)
       return -1;
     codec->frame = avcodec_alloc_frame();
@@ -632,7 +635,8 @@ static void resync_ffmpeg(quicktime_t *file, int track)
       {
       buffer_size = lqt_read_video_frame(file, &codec->buffer,
                                          &codec->buffer_alloc,
-                                         frame, NULL, track);
+                                         frame + codec->decoding_delay,
+                                         NULL, track);
       if(buffer_size > 0)
         {
 #if LIBAVCODEC_BUILD >= ((52<<16)+(26<<8)+0)
@@ -649,6 +653,11 @@ static void resync_ffmpeg(quicktime_t *file, int track)
                              codec->buffer,
                              buffer_size);
 #endif
+        if(!got_pic)
+          {
+          codec->decoding_delay++;
+          frame--;
+          }
         }
       frame++;
       }
@@ -811,6 +820,10 @@ static int lqt_ffmpeg_encode_video(quicktime_t *file, unsigned char **row_pointe
               }
             }
           /* Open codec */
+
+          codec->avctx->codec_id = codec->decoder->id;
+          codec->avctx->codec_type = codec->decoder->type;
+
           if(avcodec_open(codec->avctx, codec->encoder) != 0)
             return -1;
           codec->buffer_alloc = width * height * 4 + 1024*256;
