@@ -1,9 +1,34 @@
-#include "funcprotos.h"
-#include <stdio.h>
+/*******************************************************************************
+ lame_codec.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include <lame/lame.h>
 #include <stdlib.h>
 #include <string.h>
-#include <lame/lame.h>
-#include <quicktime/quicktime.h>
+#include <lame_codec.h>
+
+#define LOG_DOMAIN "lame"
 
 /*
  *  We decode all headers to figure out, how many COMPLETE frames we have encoded.
@@ -77,7 +102,6 @@ static int header_check(uint32_t head)
                 return 0;
         if ((head & 0xffff0000) == 0xfffe0000)
                 return 0;
-        //        fprintf(stderr, "Head check ok %08x\n", head);
         return 1;
 }
 
@@ -322,7 +346,7 @@ static int write_data(quicktime_t *file, int track,
     {
     if(!decode_header(&h, chunk_ptr))
       {
-      fprintf(stderr, "Ouch: lame created non mp3 data\n");
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "Ouch: lame created non mp3 data\n");
       break;
       }
     if(codec->encoder_output_size >= h.frame_bytes)
@@ -331,7 +355,6 @@ static int write_data(quicktime_t *file, int track,
       chunk_ptr += h.frame_bytes;
       chunk_bytes += h.frame_bytes;
       chunk_samples += h.samples_per_frame;
-      //      fprintf(stderr, "Created frame %d bytes\n", h.frame_bytes);
       }
     else
       break;
@@ -345,7 +368,7 @@ static int write_data(quicktime_t *file, int track,
       result = !quicktime_write_data(file, codec->encoder_output, chunk_bytes);
       quicktime_write_chunk_footer(file, 
                                    track_map->track, 
-                                   track_map->current_chunk,
+                                   track_map->cur_chunk,
                                    &chunk_atom,
                                    chunk_samples);
       if(file->total_riffs == 1)
@@ -367,7 +390,7 @@ static int write_data(quicktime_t *file, int track,
         lqt_finish_audio_vbr_frame(file, track, chunk_samples);
         quicktime_write_chunk_footer(file, 
                                      track_map->track, 
-                                     track_map->current_chunk,
+                                     track_map->cur_chunk,
                                      &chunk_atom,
                                      track_map->vbr_num_frames);
         codec->samples_written += chunk_samples;
@@ -377,24 +400,20 @@ static int write_data(quicktime_t *file, int track,
         lqt_finish_audio_vbr_frame(file, track, samples);
         quicktime_write_chunk_footer(file, 
                                      track_map->track, 
-                                     track_map->current_chunk,
+                                     track_map->cur_chunk,
                                      &chunk_atom,
                                      track_map->vbr_num_frames);
         codec->samples_written += samples;
         }
       }
     
-    track_map->current_chunk++;
+    track_map->cur_chunk++;
 
     /* Adjust mp3 buffer */
 
     if(codec->encoder_output_size)
       memmove(codec->encoder_output, chunk_ptr, codec->encoder_output_size);
     
-#if 0
-    fprintf(stderr, "Encoded %d samples %d bytes %d remaining\n",
-            chunk_samples, chunk_bytes, codec->encoder_output_size);
-#endif   
     }
   
   
@@ -480,7 +499,7 @@ static int encode(quicktime_t *file,
     //    lame_set_padding_type(codec->lame_global, PAD_ALL); // PAD_NO | PAD_ALL | PAD_ADJUST
     
     if((result = lame_init_params(codec->lame_global)) < 0)
-      printf(" lame_init_params returned %d\n", result);
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "lame_init_params returned %d\n", result);
     //    codec->encoded_header = mpeg3_new_layer();
     codec->samples_per_frame = lame_get_framesize(codec->lame_global);
 
@@ -592,7 +611,7 @@ static int encode(quicktime_t *file,
 
 
 static int set_parameter(quicktime_t *file, int track, 
-                         char *key, void *value)
+                         const char *key, const void *value)
   {
   quicktime_audio_map_t *atrack = &(file->atracks[track]);
   quicktime_mp3_codec_t *codec =
@@ -617,8 +636,6 @@ static int set_parameter(quicktime_t *file, int track,
     codec->quality = *(int*)value;
   else if(!strcasecmp(key, "mp3_quality_vbr"))
     codec->quality_vbr = *(int*)value;
-  else
-    fprintf(stderr, "set_parameter: %s\n", key);
   
   return 0;
   }
@@ -640,14 +657,12 @@ static int flush(quicktime_t *file, int track)
 
     if(result > 0)
       {
-      //      fprintf(stderr, "Flush: %d\n", result);
       codec->encoder_output_size += result;
       write_data(file, track, codec, codec->samples_read - codec->samples_written);
       return 1;
       }
     }
   return 0;
-  //  fprintf(stderr, "Samples read: %lld, Samples written: %lld\n", codec->samples_read, codec->samples_written);
   }
 
 void quicktime_init_codec_lame(quicktime_audio_map_t *atrack)
