@@ -1,29 +1,35 @@
-/*
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 
- * USA
- */
+/*******************************************************************************
+ libmjpeg.c
 
-#include <inttypes.h>
-#include "config.h"
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>	/* for memcpy & bzero prototypes */
-#include "funcprotos.h"
-#include "colormodels.h"
-#include "lqt.h"
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 #include "libmjpeg.h"
+#include <quicktime/colormodels.h>
+#include <stdlib.h>
+#include <string.h>
+#include <strings.h>
+
+#define LOG_DOMAIN "libmjpeg"
 
 /* JPEG MARKERS */
 #define   M_SOF0    0xc0
@@ -182,7 +188,7 @@ METHODDEF(void) term_destination(j_compress_ptr cinfo)
   dest->engine->output_size = dest->engine->output_allocated - dest->pub.free_in_buffer;
   }
 
-GLOBAL(void) jpeg_buffer_dest(j_compress_ptr cinfo, mjpeg_compressor *engine)
+static GLOBAL(void) jpeg_buffer_dest(j_compress_ptr cinfo, mjpeg_compressor *engine)
   {
   mjpeg_dest_ptr dest;
 
@@ -231,7 +237,6 @@ METHODDEF(boolean) fill_input_buffer(j_decompress_ptr cinfo)
   src->pub.next_input_byte = src->buffer;
   src->pub.bytes_in_buffer = 2;
 
-  fprintf(stderr, "fill_input_buffer\n");
   
   return TRUE;
   }
@@ -250,7 +255,7 @@ METHODDEF(void) term_source(j_decompress_ptr cinfo)
   {
   }
 
-GLOBAL(void) jpeg_buffer_src(j_decompress_ptr cinfo, unsigned char *buffer, long bytes)
+static GLOBAL(void) jpeg_buffer_src(j_decompress_ptr cinfo, unsigned char *buffer, long bytes)
   {
   mjpeg_src_ptr src;
 
@@ -373,7 +378,7 @@ static void allocate_temps(mjpeg_t *mjpeg)
     }
   }
 
-static int get_input_row(mjpeg_t *mjpeg, mjpeg_compressor *compressor, int i, int field)
+static int get_input_row(mjpeg_t *mjpeg, int i, int field)
   {
   int input_row;
   if(mjpeg->fields > 1) 
@@ -388,6 +393,10 @@ static int get_input_row(mjpeg_t *mjpeg, mjpeg_compressor *compressor, int i, in
 static void get_rows(mjpeg_t *mjpeg, mjpeg_compressor *compressor, int field)
   {
   int i;
+
+  if((mjpeg->fields > 1) && (mjpeg->bottom_first))
+    field = 1 - field;
+    
   switch(mjpeg->jpeg_color_model)
     {
     case BC_YUVJ444P:
@@ -401,7 +410,7 @@ static void get_rows(mjpeg_t *mjpeg, mjpeg_compressor *compressor, int field)
 
       for(i = 0; i < compressor->field_h; i++)
         {
-        int input_row = get_input_row(mjpeg, compressor, i, field);
+        int input_row = get_input_row(mjpeg, i, field);
         compressor->rows[0][i] = mjpeg->temp_rows[0][input_row];
         compressor->rows[1][i] = mjpeg->temp_rows[1][input_row];
         compressor->rows[2][i] = mjpeg->temp_rows[2][input_row];
@@ -420,7 +429,7 @@ static void get_rows(mjpeg_t *mjpeg, mjpeg_compressor *compressor, int field)
 
       for(i = 0; i < compressor->field_h; i++)
         {
-        int input_row = get_input_row(mjpeg, compressor, i, field);
+        int input_row = get_input_row(mjpeg, i, field);
         compressor->rows[0][i] = mjpeg->temp_rows[0][input_row];
         compressor->rows[1][i] = mjpeg->temp_rows[1][input_row];
         compressor->rows[2][i] = mjpeg->temp_rows[2][input_row];
@@ -439,7 +448,7 @@ static void get_rows(mjpeg_t *mjpeg, mjpeg_compressor *compressor, int field)
 
       for(i = 0; i < compressor->field_h; i++)
         {
-        int input_row = get_input_row(mjpeg, compressor, i, field);
+        int input_row = get_input_row(mjpeg, i, field);
         compressor->rows[0][i] = mjpeg->temp_rows[0][input_row];
         if(i < compressor->field_h / 2)
           {
@@ -527,7 +536,7 @@ static void add_huff_table (j_decompress_ptr dinfo,
     nsymbols += bits[len];
   if (nsymbols < 1 || nsymbols > 256)
     //    mjpeg_error_exit1("jpegutils.c:  add_huff_table failed badly. ");
-    fprintf(stderr, "add_huff_table failed badly.\n");
+    lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN, "add_huff_table failed badly.\n");
   
   memcpy((*htblptr)->huffval, val, nsymbols * sizeof(UINT8));
 }
@@ -624,7 +633,6 @@ static void decompress_field(mjpeg_compressor *engine, int field)
   unsigned char *buffer = mjpeg->input_data + buffer_offset;
   long buffer_size;
 
-  //  fprintf(stderr, "** DECOMPRESS_FIELD\n");
 
   if(mjpeg->fields > 1)
     {
@@ -650,13 +658,10 @@ static void decompress_field(mjpeg_compressor *engine, int field)
   jpeg_buffer_src(&engine->jpeg_decompress, 
                   buffer, 
                   buffer_size);
-  //  fprintf(stderr, "Read header %d (buf: %p, size: %d...\n", field, buffer, 
-  //          buffer_size);
   jpeg_read_header(&engine->jpeg_decompress, TRUE);
   guarantee_huff_tables(&engine->jpeg_decompress);
 
 
-  //  fprintf(stderr, "Read header done\n");
   
   // Reset by jpeg_read_header
   engine->jpeg_decompress.raw_data_out = TRUE;
@@ -702,7 +707,6 @@ static void compress_field(mjpeg_compressor *engine, int field)
   {
   mjpeg_t *mjpeg = engine->mjpeg;
 
-  //printf("compress_field 1\n");
   get_rows(engine->mjpeg, engine, field);
   reset_buffer(&engine->output_buffer, &engine->output_size, &engine->output_allocated);
   jpeg_buffer_dest(&engine->jpeg_compress, engine);
@@ -720,7 +724,6 @@ static void compress_field(mjpeg_compressor *engine, int field)
 			engine->field_h);
     }
   jpeg_finish_compress(&engine->jpeg_compress);
-  //printf("compress_field 2\n");
   }
 
 
@@ -736,7 +739,7 @@ static void delete_temps(mjpeg_t *mjpeg)
     }
   }
 
-mjpeg_compressor* mjpeg_new_decompressor(mjpeg_t *mjpeg)
+static mjpeg_compressor* mjpeg_new_decompressor(mjpeg_t *mjpeg)
   {
   mjpeg_compressor *result = lqt_bufalloc(sizeof(mjpeg_compressor));
 
@@ -751,7 +754,7 @@ mjpeg_compressor* mjpeg_new_decompressor(mjpeg_t *mjpeg)
   return result;
   }
 
-void mjpeg_delete_decompressor(mjpeg_compressor *engine)
+static void mjpeg_delete_decompressor(mjpeg_compressor *engine)
   {
   /*
    * Must honor the locking protocol to avoid a race condition with
@@ -766,7 +769,7 @@ void mjpeg_delete_decompressor(mjpeg_compressor *engine)
   free(engine);
   }
 
-mjpeg_compressor* mjpeg_new_compressor(mjpeg_t *mjpeg)
+static mjpeg_compressor* mjpeg_new_compressor(mjpeg_t *mjpeg)
   {
   mjpeg_compressor *result = lqt_bufalloc(sizeof(mjpeg_compressor));
 
@@ -793,16 +796,35 @@ mjpeg_compressor* mjpeg_new_compressor(mjpeg_t *mjpeg)
   switch(mjpeg->fields)
     {
     case 1:
-      mjpeg->jpeg_color_model = BC_YUVJ420P;
-      result->jpeg_compress.comp_info[0].h_samp_factor = 2;
-      result->jpeg_compress.comp_info[0].v_samp_factor = 2;
-      result->jpeg_compress.comp_info[1].h_samp_factor = 1;
-      result->jpeg_compress.comp_info[1].v_samp_factor = 1;
-      result->jpeg_compress.comp_info[2].h_samp_factor = 1;
-      result->jpeg_compress.comp_info[2].v_samp_factor = 1;
+      if(mjpeg->jpeg_color_model == BC_YUVJ420P)
+        {
+        result->jpeg_compress.comp_info[0].h_samp_factor = 2;
+        result->jpeg_compress.comp_info[0].v_samp_factor = 2;
+        result->jpeg_compress.comp_info[1].h_samp_factor = 1;
+        result->jpeg_compress.comp_info[1].v_samp_factor = 1;
+        result->jpeg_compress.comp_info[2].h_samp_factor = 1;
+        result->jpeg_compress.comp_info[2].v_samp_factor = 1;
+        }
+      else if(mjpeg->jpeg_color_model == BC_YUVJ422P)
+        {
+        result->jpeg_compress.comp_info[0].h_samp_factor = 2;
+        result->jpeg_compress.comp_info[0].v_samp_factor = 1;
+        result->jpeg_compress.comp_info[1].h_samp_factor = 1;
+        result->jpeg_compress.comp_info[1].v_samp_factor = 1;
+        result->jpeg_compress.comp_info[2].h_samp_factor = 1;
+        result->jpeg_compress.comp_info[2].v_samp_factor = 1;
+        }
+      else if(mjpeg->jpeg_color_model == BC_YUVJ444P)
+        {
+        result->jpeg_compress.comp_info[0].h_samp_factor = 1;
+        result->jpeg_compress.comp_info[0].v_samp_factor = 1;
+        result->jpeg_compress.comp_info[1].h_samp_factor = 1;
+        result->jpeg_compress.comp_info[1].v_samp_factor = 1;
+        result->jpeg_compress.comp_info[2].h_samp_factor = 1;
+        result->jpeg_compress.comp_info[2].v_samp_factor = 1;
+        }
       break;
     case 2:
-      mjpeg->jpeg_color_model = BC_YUVJ422P;
       result->jpeg_compress.comp_info[0].h_samp_factor = 2;
       result->jpeg_compress.comp_info[0].v_samp_factor = 1;
       result->jpeg_compress.comp_info[1].h_samp_factor = 1;
@@ -820,7 +842,7 @@ mjpeg_compressor* mjpeg_new_compressor(mjpeg_t *mjpeg)
   return result;
   }
 
-void mjpeg_delete_compressor(mjpeg_compressor *engine)
+static void mjpeg_delete_compressor(mjpeg_compressor *engine)
   {
   /*
    * Must honor the locking protocol to avoid a race condition with 
@@ -857,7 +879,6 @@ int mjpeg_compress(mjpeg_t *mjpeg,
   uint8_t * cpy_rows[3];
   int i;
 
-  //printf("mjpeg_compress 1 %d\n", color_model);
   /* Reset output buffer */
   reset_buffer(&mjpeg->output_data, 
                &mjpeg->output_size, 
@@ -893,7 +914,6 @@ int mjpeg_compress(mjpeg_t *mjpeg,
     if(i == 0) mjpeg->output_field2 = mjpeg->output_size;
     }	
 
-  //printf("mjpeg_compress 2\n");
   return 0;
   }
 
@@ -905,21 +925,16 @@ int mjpeg_decompress(mjpeg_t *mjpeg,
   {
   int i;
 
-  //printf("mjpeg_decompress 1 %ld %ld\n", buffer_len, input_field2);
   if(buffer_len == 0) return 1;
   if(input_field2 == 0 && mjpeg->fields > 1) return 1;
 
-  //  fprintf(stderr, "mjpeg_decompress: %p %ld %ld\n", buffer, 
-  //          buffer_len, input_field2);
     
-  //printf("mjpeg_decompress 2\n");
   /* Create decompression engines as needed */
   if(!mjpeg->decompressor)
     {
     mjpeg->decompressor = mjpeg_new_decompressor(mjpeg);
     }
   
-  //printf("mjpeg_decompress 3\n");
   /* Arm YUV buffers */
   //	mjpeg->y_argument = y_plane;
   //	mjpeg->u_argument = u_plane;
@@ -978,10 +993,10 @@ int mjpeg_get_fields(mjpeg_t *mjpeg)
 
 mjpeg_t* mjpeg_new(int w, 
                    int h, 
-                   int fields)
+                   int fields, int cmodel)
   {
-  mjpeg_t *result = lqt_bufalloc(sizeof(mjpeg_t));
-
+  mjpeg_t *result = calloc(1, sizeof(*result));
+  
   result->output_w = w;
   result->output_h = h;
   result->fields = fields;
@@ -989,11 +1004,17 @@ mjpeg_t* mjpeg_new(int w,
   result->use_float = 0;
   
   // Calculate coded dimensions
+  result->jpeg_color_model = cmodel;
 
   result->coded_w = (w % 16) ? w + (16 - (w % 16)) : w;
-  result->coded_w_uv = result->coded_w / 2;
+
+  if(result->jpeg_color_model == BC_YUVJ444P)
+    result->coded_w_uv = result->coded_w;
+  else
+    result->coded_w_uv = result->coded_w / 2;
   
   result->coded_h = (h % 16) ? h + (16 - (h % 16)) : h;
+
   
   return result;
   }
@@ -1067,7 +1088,8 @@ static inline int read_int16(unsigned char *data, long *offset, long length)
           (((unsigned int)data[*offset - 1])));
   }
 
-static inline int next_int16(unsigned char *data, long *offset, long length)
+static inline int
+next_int16(unsigned char *data, long *offset, long length)
   {
   if(length - *offset < 2)	
     {
@@ -1078,7 +1100,9 @@ static inline int next_int16(unsigned char *data, long *offset, long length)
           (((unsigned int)data[*offset + 1])));
   }
 
-static inline void write_int32(unsigned char *data, long *offset, long length, unsigned int value)
+static inline void
+write_int32(unsigned char *data, long *offset, long length,
+            unsigned int value)
   {
   if(length - *offset < 4)
     {
@@ -1142,9 +1166,11 @@ typedef struct
   int data_offset;
   } mjpeg_qt_hdr;
 
+#if 0
+
 #define LML_MARKER_SIZE 0x2c
 #define LML_MARKER_TAG 0xffe3
-void insert_lml33_markers(unsigned char **buffer, 
+static void insert_lml33_markers(unsigned char **buffer, 
                           long *field2_offset, 
                           long *buffer_size, 
                           long *buffer_allocated)
@@ -1165,6 +1191,7 @@ void insert_lml33_markers(unsigned char **buffer,
                  LML_MARKER_SIZE);
     }
   }
+#endif
 
 static void table_offsets(unsigned char *buffer, 
                           long buffer_size, 
@@ -1182,7 +1209,6 @@ static void table_offsets(unsigned char *buffer,
   for(field = 0; field < 2; field++)
     {
     done = 0;
-    //printf("table_offsets 1 %d %d\n", field, offset);
     while(!done)
       {
       marker = next_marker(buffer, 
@@ -1201,11 +1227,9 @@ static void table_offsets(unsigned char *buffer,
               offset - 2;
             }
           len = 0;
-          //printf("table_offsets 1 %x %d\n", header[0].next_offset, field);
           break;
 
         case M_DQT:
-          //printf("table_offsets M_DQT %d %d\n", field, offset);
           if(!header[field].quant_offset)
             {
             header[field].quant_offset = offset - 2;
@@ -1265,7 +1289,6 @@ static void table_offsets(unsigned char *buffer,
             //							header[0].padded_field_size = 
             //							offset;
             }
-          //printf("table_offsets M_EOI %d %x\n", field, offset);
           done = 1;
           len = 0;
           break;
@@ -1315,10 +1338,6 @@ void mjpeg_insert_quicktime_markers(unsigned char **buffer,
   if(fields < 2) return;
   // Get offsets for tables in both fields
   table_offsets(*buffer, *buffer_size, header);
-  //printf("mjpeg_insert_quicktime_markers %x %02x %02x\n", 
-  //	header[0].next_offset, (*buffer)[*field2_offset], (*buffer)[*field2_offset + 1]);
-  //if(*field2_offset == 0)
-  //	fwrite(*buffer, *buffer_size, 1, stdout);
 
   header[0].field_size += QUICKTIME_MARKER_SIZE;
   header[0].padded_field_size += QUICKTIME_MARKER_SIZE;
@@ -1408,22 +1427,3 @@ long mjpeg_get_quicktime_field2(unsigned char *buffer, long buffer_size)
   read_quicktime_markers(buffer, buffer_size, header);
   return header[0].next_offset;
   }
-
-long mjpeg_get_field2(unsigned char *buffer, long buffer_size)
-  {
-  int total_fields = 0;
-  long field2_offset = 0;
-  int i;
-
-  for(i = 0; i < buffer_size; i++)
-    {
-    if(buffer[i] == 0xff && buffer[i + 1] == M_SOI)
-      {
-      total_fields++;
-      field2_offset = i;
-      if(total_fields == 2) break;
-      }
-    }
-  return field2_offset;
-  }
-
