@@ -1,38 +1,37 @@
-/*
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 
- * USA
- */
+/*******************************************************************************
+ libmjpeg.h
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
  
 #ifndef LIBMJPEG_H
 #define LIBMJPEG_H
 
-
-/* Motion JPEG library */
-
-
-
 /* use a thread to run compressors / decompressors */
 // #define USE_THREAD 0
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-
-
 #include <stdio.h>
 #include <jpeglib.h>
 #include <setjmp.h>
@@ -42,6 +41,7 @@ extern "C" {
 #define QUICKTIME_JPEG_TAG 0x6d6a7067
 
 
+
   struct mjpeg_error_mgr {
   struct jpeg_error_mgr pub;	/* "public" fields */
   jmp_buf setjmp_buffer;	/* for return to caller */
@@ -49,17 +49,6 @@ extern "C" {
 
   typedef struct mjpeg_error_mgr* mjpeg_error_ptr;
 
-#ifndef __alpha__
-  typedef struct
-    {
-    } mjpeg_lml_hdr;
-
-  typedef struct
-    {
-    } mjpeg_dc10_hdr;
-#endif
-
-
   // The compressor structure is shared between decompressors and compressors
   typedef struct
     {
@@ -120,6 +109,9 @@ extern "C" {
     long input_field2;
     int rowspan, rowspan_uv;
 
+    // Bottom first needs special treatment
+    int bottom_first;
+        
     } mjpeg_t;
 
 
@@ -127,7 +119,7 @@ extern "C" {
 
 
   // Entry points
-  mjpeg_t* mjpeg_new(int w, int h, int fields);
+  mjpeg_t* mjpeg_new(int w, int h, int fields, int cmodel);
   void mjpeg_delete(mjpeg_t *mjpeg);
 
   void mjpeg_set_quality(mjpeg_t *mjpeg, int quality);
@@ -164,10 +156,7 @@ extern "C" {
                                       long *field2_offset);
 
   // Get the second field offset from the markers
-  long mjpeg_get_buz_field2(unsigned char *buffer, long buffer_size);
-  long mjpeg_get_lml33_field2(unsigned char *buffer, long buffer_size);
   long mjpeg_get_quicktime_field2(unsigned char *buffer, long buffer_size);
-  long mjpeg_get_field2(unsigned char *buffer, long buffer_size);
 
 #ifdef __cplusplus
 }
