@@ -252,7 +252,6 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 {
 	quicktime_video_map_t *vtrack = &(file->vtracks[track]);
 	quicktime_yuv4_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-	quicktime_trak_t *trak = vtrack->track;
 	int result = 0;
 	int width = vtrack->track->tkhd.track_width;
 	int height = vtrack->track->tkhd.track_height;
@@ -266,7 +265,6 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 	int u, v;
 	int r, g, b;
 	int bytes_per_row = width * 3;
-	quicktime_atom_t chunk_atom;
 
         if(!row_pointers)
           {
