@@ -67,7 +67,11 @@ static void dump_params(x264_param_t * params)
   lqt_dump("  i_bframe:                    %d\n", params->i_bframe);          // 0.. X264_BFRAME_MAX
   lqt_dump("  b_bframe_adaptive:           %d\n", params->b_bframe_adaptive);
   lqt_dump("  i_bframe_bias:               %d\n", params->i_bframe_bias);
+#if X264_BUILD >= 78
+  lqt_dump("  i_bframe_pyramid:            %d\n", params->i_bframe_pyramid);
+#else
   lqt_dump("  b_bframe_pyramid:            %d\n", params->b_bframe_pyramid);
+#endif
   
   lqt_dump("  b_deblocking_filter:         %d\n", params->b_deblocking_filter);
   lqt_dump("  i_deblocking_filter_alphac0: %d\n", params->i_deblocking_filter_alphac0); // -6..6
@@ -107,6 +111,16 @@ static void dump_params(x264_param_t * params)
   lqt_dump("    i_trellis:          %d\n", params->analyse.i_trellis);         // 0..2
   lqt_dump("    b_fast_pskip:       %d\n", params->analyse.b_fast_pskip);
   lqt_dump("    i_noise_reduction:  %d\n", params->analyse.i_noise_reduction); // 0..1<<16
+#if X264_BUILD >= 63
+  lqt_dump("    f_psy_rd            %.2f\n", params->analyse.f_psy_rd);
+  lqt_dump("    f_psy_trellis       %.2f\n", params->analyse.f_psy_trellis);
+#endif
+
+#if X264_BUILD >= 69
+  lqt_dump("    b_psy:              %d\n", params->analyse.b_psy);
+#endif  
+
+
   lqt_dump("    b_psnr:             %d\n", params->analyse.b_psnr);
 
   lqt_dump("  Rate control:\n");
@@ -127,7 +141,14 @@ static void dump_params(x264_param_t * params)
   lqt_dump("    f_vbv_buffer_init:  %f\n", params->rc.f_vbv_buffer_init);
   lqt_dump("    f_ip_factor:        %f\n", params->rc.f_ip_factor);
   lqt_dump("    f_pb_factor:        %f\n", params->rc.f_pb_factor);
-  
+#if X264_BUILD >= 62
+  lqt_dump("    i_aq_mode:          %d\n", params->rc.i_aq_mode);
+  lqt_dump("    f_aq_strength:      %f\n", params->rc.f_aq_strength);
+#endif  
+#if X264_BUILD >= 69
+  lqt_dump("    b_mb_tree:          %d\n", params->rc.b_mb_tree);
+  lqt_dump("    i_lookahead:        %d\n", params->rc.i_lookahead);
+#endif  
   }
 
 #endif // DUMP_CONFIG
@@ -163,8 +184,19 @@ static int delete_codec(quicktime_video_map_t *vtrack)
   quicktime_x264_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
   if(codec->enc)
     x264_encoder_close(codec->enc);
-  if(codec->stats_filename)
+  
+  if(codec->stats_filename && (codec->pass == codec->total_passes))
+    {
+    char * mbtree_file = malloc(strlen(codec->stats_filename) + 8);
+
+    strcpy(mbtree_file, codec->stats_filename);
+    strcat(mbtree_file, ".mbtree");
+
+    remove(mbtree_file);
+    free(mbtree_file);
+    
     free(codec->stats_filename);
+    }
   free(codec);
   return 0;
   }
@@ -174,14 +206,21 @@ encode_nals(uint8_t *buf, int size, x264_nal_t *nals, int nnal)
   {
   uint8_t *p = buf;
   int i;
+#if X264_BUILD < 76
   int s;
+#endif
   
   for(i = 0; i < nnal; i++)
     {
+#if X264_BUILD >= 76
+    memcpy(p, nals[i].p_payload, nals[i].i_payload);
+    p+=nals[i].i_payload;
+#else
     s = x264_nal_encode(p, &size, 1, nals + i);
     if(s < 0)
       return -1;
     p += s;
+#endif
     }
   
   return p - buf;
@@ -407,7 +446,11 @@ static int flush_frame(quicktime_t *file, int track,
 
   pic_out.i_pts = 0;
   /* Encode frames, get nals */
+#if X264_BUILD >= 76
+  if(x264_encoder_encode(codec->enc, &nal, &nnal, pic_in, &pic_out)<0)
+#else
   if(x264_encoder_encode(codec->enc, &nal, &nnal, pic_in, &pic_out))
+#endif
     return 0;
   
   /* Encode nals -> get h264 stream */
@@ -607,7 +650,12 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
     if(codec->total_passes)
       {
       /* Force ABR */
-      codec->params.rc.i_rc_method = X264_RC_ABR;
+      if(codec->params.rc.i_rc_method != X264_RC_ABR)
+        {
+        lqt_log(file, LQT_LOG_INFO, LOG_DOMAIN,
+              "Forcing average bitrate for multipass encoding");
+        codec->params.rc.i_rc_method = X264_RC_ABR;
+        }
 #if X264_BUILD < 54
       codec->params.rc.i_rf_constant = 0;
 #else
@@ -627,6 +675,15 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
         }
       }
 
+    /* Sanity check for bitrate */
+    if((codec->params.rc.i_rc_method == X264_RC_ABR) &&
+       (!codec->params.rc.i_bitrate))
+      {
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN,
+              "Need non-zero bitrate for this mode");
+      return 1;
+      }
+    
 #ifdef DUMP_CONFIG    
     dump_params(&codec->params);
 #endif
@@ -638,7 +695,7 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
     if(!codec->enc)
       {
       lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "x264_encoder_open failed");
-      return result;
+      return 1;
       }
     
     /* Encode global header */
@@ -650,8 +707,6 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
     file->moov.iods.videoProfileId = 0x15;
     
     codec->initialized = 1;
-
-    
     }
 
   /* Encode picture */
@@ -728,7 +783,10 @@ enum_t me_methods[] =
     { "Diamond search",       X264_ME_DIA },
     { "Hexagonal search",     X264_ME_HEX },
     { "Uneven Multi-Hexagon", X264_ME_UMH },
-    { "Exhaustive search",    X264_ME_ESA }
+    { "Exhaustive search",    X264_ME_ESA },
+#if X264_BUILD > 57
+    { "Hadamard exhaustive search (slow)", X264_ME_TESA },
+#endif
   };
 
 enum_t trellis[] =
@@ -762,6 +820,19 @@ enum_t bframe_adaptives[] =
   };
 #endif
 
+#if X264_BUILD >= 62
+enum_t aq_modes[] =
+  {
+    { "None",      X264_AQ_NONE },
+    { "Variance AQ (complexity mask)",  X264_AQ_VARIANCE },
+#if X264_BUILD >= 69
+    { "Autovariance AQ (experimental)", X264_AQ_AUTOVARIANCE },
+#endif
+
+  };
+#endif
+
+
 static int set_parameter(quicktime_t *file, 
                          int track, 
                          const char *key, 
@@ -782,7 +853,11 @@ static int set_parameter(quicktime_t *file,
   ENUMPARAM("x264_i_bframe_adaptive", codec->params.i_bframe_adaptive, bframe_adaptives);
 #endif
   INTPARAM("x264_i_bframe_bias", codec->params.i_bframe_bias);
+#if X264_BUILD >= 78
+  INTPARAM("x264_i_bframe_pyramid", codec->params.i_bframe_pyramid);
+#else
   INTPARAM("x264_b_bframe_pyramid", codec->params.b_bframe_pyramid);
+#endif
 
   ENUMPARAM("x264_i_rc_method", codec->params.rc.i_rc_method, rc_methods);
   INTPARAM("x264_i_bitrate", codec->params.rc.i_bitrate);
@@ -802,6 +877,17 @@ static int set_parameter(quicktime_t *file,
   FLOATPARAM("x264_f_vbv_buffer_init", codec->params.rc.f_vbv_buffer_init);
   FLOATPARAM("x264_f_ip_factor", codec->params.rc.f_ip_factor);
   FLOATPARAM("x264_f_pb_factor", codec->params.rc.f_pb_factor);
+
+#if X264_BUILD >= 62
+  ENUMPARAM("x264_i_aq_mode", codec->params.rc.i_aq_mode, aq_modes);
+  FLOATPARAM("x264_f_aq_strength", codec->params.rc.f_aq_strength);
+#endif  
+
+#if X264_BUILD >= 69
+  INTPARAM("x264_b_mb_tree", codec->params.rc.b_mb_tree);
+  INTPARAM("x264_i_lookahead", codec->params.rc.i_lookahead);
+#endif  
+  
   INTPARAM("x264_analyse_8x8_transform", codec->params.analyse.b_transform_8x8);
 
   if(!strcasecmp(key, "x264_analyse_psub16x16"))
@@ -893,6 +979,11 @@ static int set_parameter(quicktime_t *file,
   ENUMPARAM("x264_i_trellis", codec->params.analyse.i_trellis, trellis);
 
   INTPARAM("x264_i_noise_reduction", codec->params.analyse.i_noise_reduction);
+
+#if X264_BUILD >= 63
+  FLOATPARAM("x264_f_psy_rd", codec->params.analyse.f_psy_rd);
+  FLOATPARAM("x264_f_psy_trellis", codec->params.analyse.f_psy_trellis);
+#endif
   
   if(!found)
     lqt_log(file, LQT_LOG_WARNING, LOG_DOMAIN,
