@@ -1,6 +1,29 @@
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ avi_idx1.c
 
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include <stdlib.h>
 #include <string.h>
 
 typedef struct
@@ -31,6 +54,26 @@ void quicktime_delete_idx1(quicktime_idx1_t *idx1)
 	if(idx1->table) free(idx1->table);
 }
 
+void quicktime_idx1_dump(quicktime_idx1_t *idx1)
+{
+	int i;
+        lqt_dump("idx1\n");
+        for(i = 0; i < idx1->table_size; i++)
+	{
+		quicktime_idx1table_t *idx1table = idx1->table + i;
+                lqt_dump("  T: %c%c%c%c, F: %08x, O: %d, S: %d\n",
+                         idx1table->tag[0],
+                         idx1table->tag[1],
+                         idx1table->tag[2],
+                         idx1table->tag[3],
+                         idx1table->flags,
+                         idx1table->offset,
+                         idx1table->size);
+	}
+
+}
+
+
 void quicktime_read_idx1(quicktime_t *file, 
 	quicktime_riff_t *riff,
 	quicktime_atom_t *parent_atom)
@@ -38,13 +81,17 @@ void quicktime_read_idx1(quicktime_t *file,
 	int i;
 	quicktime_idx1_t *idx1 = &riff->idx1;
 
-//printf("quicktime_read_idx1 1 %llx\n", quicktime_position(file));
 
 // Allocate table.
 	idx1->table_size = (parent_atom->end - quicktime_position(file)) / 16;
+
+        if(idx1->table_size <= 0)
+          {
+          idx1->table_size = 0;
+          return;
+          }
 	idx1->table_allocation = idx1->table_size;
 	idx1->table = calloc(sizeof(quicktime_idx1table_t), idx1->table_size);
-//printf("quicktime_read_idx1 10\n");
 
 // Store it in idx1 table now.
 // Wait for full ix table discovery before converting to stco.
@@ -58,7 +105,6 @@ void quicktime_read_idx1(quicktime_t *file,
 		idx1table->size = quicktime_read_int32_le(file);
 	}
 
-//printf("quicktime_read_idx1 100\n");
 
 
 }
@@ -71,7 +117,6 @@ void quicktime_write_idx1(quicktime_t *file,
 	int table_size = idx1->table_size;
 
 
-        //        fprintf(stderr, "Writing idx1 %llx\n", quicktime_position(file));
 // Write table
 	quicktime_atom_write_header(file, &idx1->atom, "idx1");
 
@@ -122,8 +167,7 @@ void quicktime_update_idx1table(quicktime_t *file,
 	int size)
 {
 	quicktime_riff_t *riff = file->riff[0];
-	quicktime_hdrl_t *hdrl = &riff->hdrl;
-	quicktime_strl_t *strl = hdrl->strl[trak->tkhd.track_id - 1];
+	quicktime_strl_t *strl = trak->strl;
 	char *tag = strl->tag;
 	quicktime_idx1_t *idx1 = &riff->idx1;
 	quicktime_movi_t *movi = &riff->movi;
