@@ -1,17 +1,33 @@
-#include <quicktime/lqt.h>
-#include <qtprivate.h>
+/*******************************************************************************
+ lqt_color.c
 
-#include <quicktime/colormodels.h>
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include "quicktime/colormodels.h"
+#include <stdlib.h>
 #include <string.h>
-#include <dlfcn.h>
 
-#ifndef NDEBUG
-#include <stdio.h>
-#endif
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#define LOG_DOMAIN "color"
 
 typedef struct
   {
@@ -41,7 +57,7 @@ static lqt_colormodel_tab colormodel_table[] =
     { "YUV 4:2:2 planar (jpeg)",   BC_YUVJ422P },
     { "YUV 4:4:4 planar (jpeg)",   BC_YUVJ444P },
     { "YUV 4:1:1 planar",          BC_YUV411P },
-    { (char*)0, LQT_COLORMODEL_NONE }
+    { "Undefined",                 LQT_COLORMODEL_NONE }
   };
 
 /* Some functions to find out, how cheap a colorspace conversion can be */
@@ -185,7 +201,8 @@ static int colormodel_get_bits(int colormodel)
     case BC_RGBA16161616:
       return 64;
     default:
-      fprintf(stderr,"lqt: warning: unknown colormodel (%d)\n",colormodel);
+      lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
+              "Unknown colormodel (%d)\n",colormodel);
       return 0;
     }
   }
@@ -218,20 +235,16 @@ static int get_conversion_price(int in_colormodel, int out_colormodel)
   
   if(!input_is_rgb && !input_is_yuv)
     {
-#ifndef NDEBUG
-    fprintf(stderr,
-            "Input colorspace is neither RGB nor YUV, can't predict conversion price\n");
-#endif
-    return 6;
+    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
+            "Input colorspace is neither RGB nor YUV, can't predict conversion price");
+    return 7;
     }
   
   if(!output_is_rgb && !output_is_yuv)
     {
-#ifndef NDEBUG
-    fprintf(stderr,
-            "Output colorspace is neither RGB nor YUV, can't predict conversion price\n");
-#endif
-    return 6;
+    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
+            "Output colorspace is neither RGB nor YUV, can't predict conversion price");
+    return 7;
     }
 
   /*
@@ -240,15 +253,25 @@ static int get_conversion_price(int in_colormodel, int out_colormodel)
    */
 
   if(input_has_alpha != output_has_alpha)
-    return 5;
+    return 6;
   
   /*
-   *  YUV <-> RGB conversion costs 4
+   *  YUV <-> RGB conversion costs 4-5
    */
   
   if((input_is_yuv && output_is_rgb) ||
      (input_is_rgb && output_is_yuv))
-    return 4;
+    {
+    /* Added check to make sure that staying on the same bit depth
+       is considered as "better" when doing a colorspace conversion. */
+    if(colormodel_get_bits(in_colormodel) !=
+      colormodel_get_bits(out_colormodel))
+      /* With bit conversion: 5   */
+      return 5;
+    else 
+      /* No bit conversion is better: 4   */
+      return 4;
+    }
   
   /*
    *  Alpha blending is a bit more simple
@@ -320,10 +343,6 @@ lqt_get_best_colormodel_decode(quicktime_t * file, int track, int * supported)
         {
         conversion_price
           = get_conversion_price(decoder_colormodel, supported[index]);
-/*         fprintf(stderr, "Conversion: %s -> %s: %d\n", */
-/*                 lqt_colormodel_to_string(decoder_colormodel), */
-/*                 lqt_colormodel_to_string(supported[index]), */
-/*                 conversion_price);     */
         if(conversion_price < best_conversion_price)
           {
           best_conversion_price = conversion_price;
@@ -349,14 +368,12 @@ lqt_get_best_colormodel_encode(quicktime_t * file, int track,
   
   index_supported = 0;
 
-  fprintf(stderr, "Get best colormodel %s\n", lqt_colormodel_to_string(file->vtracks[track].stream_cmodel));
 
   while(supported[index_supported] != LQT_COLORMODEL_NONE)
     {
     if(file->vtracks[track].stream_cmodel == supported[index_supported])
       {
       ret = file->vtracks[track].stream_cmodel;
-      fprintf(stderr, "*** GOT ENCODER CMODEL: %s\n", lqt_colormodel_to_string(ret));
       break;
       }
     index_supported++;
@@ -404,42 +421,30 @@ int lqt_get_best_colormodel(quicktime_t * file, int track,
     return lqt_get_best_colormodel_decode(file, track, supported);
   }
 
+static const int num_colormodels =
+  sizeof(colormodel_table)/sizeof(colormodel_table[0])-1;
+
 const char * lqt_colormodel_to_string(int colormodel)
   {
-  int index = 0;
-  
-  while(1)
-    {
-    if((colormodel_table[index].colormodel == colormodel) ||
-       (colormodel_table[index].colormodel == LQT_COLORMODEL_NONE))
+  int i = 0;
+  for(; i < num_colormodels; i++)
+    if(colormodel_table[i].colormodel == colormodel)
       break;
-    index++;
-    }
-  return colormodel_table[index].name;
+  return colormodel_table[i].name;
   }
 
 int lqt_string_to_colormodel(const char * str)
   {
-  int index = 0;
-  
-  while(1)
-    {
-    if((!colormodel_table[index].name) ||
-       !strcmp(colormodel_table[index].name, str))
+  int i = 0;
+  for(; i < num_colormodels; i++)
+    if(!strcmp(colormodel_table[i].name, str))
       break;
-    index++;
-    }
-  return colormodel_table[index].colormodel;
+  return colormodel_table[i].colormodel;
   }
 
 int lqt_num_colormodels()
   {
-  int ret = 0;
-  
-  while(colormodel_table[ret].name)
-    ret++;
-  
-  return ret;
+  return num_colormodels;
   }
 
 const char * lqt_get_colormodel_string(int index)
@@ -495,10 +500,6 @@ uint8_t ** lqt_rows_alloc(int width, int height, int colormodel, int * rowspan,
   int sub_h = 0, sub_v = 0;
 
   /* Allocate frame buffer */
-#if 0  
-  fprintf(stderr, "lqt_rows_alloc: %d x %d, %s, %d %d\n", width, height, lqt_colormodel_to_string(colormodel),
-          *rowspan, *rowspan_uv);
-#endif
   bytes_per_line = get_bytes_per_line(colormodel, width);
     
   if(cmodel_is_planar(colormodel))
@@ -509,10 +510,10 @@ uint8_t ** lqt_rows_alloc(int width, int height, int colormodel, int * rowspan,
       *rowspan = bytes_per_line;
 
     if(*rowspan_uv <= 0)
-      *rowspan_uv = *rowspan / sub_h;
+      *rowspan_uv = (*rowspan + sub_h - 1) / sub_h;
 
     y_size = *rowspan * height;
-    uv_size = (*rowspan_uv * height)/sub_v;
+    uv_size = (*rowspan_uv * (height + sub_v - 1))/sub_v;
 
     video_buffer    = malloc(3 * sizeof(unsigned char*));
     video_buffer[0] = malloc(y_size + 2 * uv_size);
@@ -545,7 +546,7 @@ void lqt_get_default_rowspan(int colormodel, int width, int * rowspan, int * row
 
   if(lqt_colormodel_is_planar(colormodel))
     {
-    *rowspan_uv = bytes_per_line / sub_h;
+    *rowspan_uv = (bytes_per_line + sub_h - 1) / sub_h;
     }
   }
 
@@ -555,18 +556,14 @@ void lqt_rows_free(uint8_t ** rows)
   free(rows);
   }
 
-void lqt_rows_copy(uint8_t **out_rows, uint8_t **in_rows, int width, int height, int in_rowspan, int in_rowspan_uv,
-                   int out_rowspan, int out_rowspan_uv, int colormodel)
+void lqt_rows_copy(uint8_t **out_rows, uint8_t **in_rows, int width, int height, int in_rowspan,
+                   int in_rowspan_uv, int out_rowspan, int out_rowspan_uv, int colormodel)
   {
   uint8_t * src_ptr, *dst_ptr;
   int i;
   int sub_h = 0, sub_v = 0;
 
   int bytes_per_line;
-#if 0
-  fprintf(stderr, "lqt_rows_copy: w: %d, h: %d, in_rowspan: %d, in_rowspan_uv: %d, out_rowspan: %d, out_rowspan_uv: %d, colormodel: %s\n",
-          width, height, in_rowspan, in_rowspan_uv, out_rowspan, out_rowspan_uv, lqt_colormodel_to_string(colormodel));
-#endif
   if(lqt_colormodel_is_planar(colormodel))
     {
     lqt_colormodel_get_chroma_sub(colormodel, &sub_h, &sub_v);
@@ -585,18 +582,18 @@ void lqt_rows_copy(uint8_t **out_rows, uint8_t **in_rows, int width, int height,
 
     src_ptr = in_rows[1];
     dst_ptr = out_rows[1];
-    for(i = 0; i < height/sub_v; i++)
+    for(i = 0; i < (height + sub_v - 1)/sub_v; i++)
       {
-      memcpy(dst_ptr, src_ptr, width/sub_h);
+      memcpy(dst_ptr, src_ptr, (width + sub_h - 1)/sub_h);
       src_ptr += in_rowspan_uv;
       dst_ptr += out_rowspan_uv;
       }
 
     src_ptr = in_rows[2];
     dst_ptr = out_rows[2];
-    for(i = 0; i < height/sub_v; i++)
+    for(i = 0; i < (height + sub_v - 1)/sub_v; i++)
       {
-      memcpy(dst_ptr, src_ptr, width/sub_h);
+      memcpy(dst_ptr, src_ptr, (width + sub_h - 1)/sub_h);
       src_ptr += in_rowspan_uv;
       dst_ptr += out_rowspan_uv;
       }
@@ -604,11 +601,50 @@ void lqt_rows_copy(uint8_t **out_rows, uint8_t **in_rows, int width, int height,
     }
   else /* Packed */
     {
+    /* This is nasty: We don't know, how the frames are allocated.
+       We test rows[1] to check this and handle all 4 combinations
+       separately */
+    
     bytes_per_line = get_bytes_per_line(colormodel, width);
-    for(i = 0; i < height; i++)
-      memcpy(out_rows[i], in_rows[i], bytes_per_line);
+    
+    if(in_rows[1] && out_rows[1])
+      {
+      for(i = 0; i < height; i++)
+        memcpy(out_rows[i], in_rows[i], bytes_per_line);
+      }
+    else if(in_rows[1])
+      {
+      dst_ptr = out_rows[0];
+      
+      for(i = 0; i < height; i++)
+        {
+        memcpy(dst_ptr, in_rows[i], bytes_per_line);
+        dst_ptr += out_rowspan;
+        }
+      }
+    else if(out_rows[1])
+      {
+      src_ptr = in_rows[0];
+      
+      for(i = 0; i < height; i++)
+        {
+        memcpy(out_rows[i], src_ptr, bytes_per_line);
+        src_ptr += in_rowspan;
+        }
+      }
+    else
+      {
+      src_ptr = in_rows[0];
+      dst_ptr = out_rows[0];
+      
+      for(i = 0; i < height; i++)
+        {
+        memcpy(dst_ptr, src_ptr, bytes_per_line);
+        src_ptr += in_rowspan;
+        dst_ptr += out_rowspan;
+        }
+      }
     }
-  
   }
 
 // for i in BC_RGB565 BC_BGR565 BC_BGR888 BC_BGR8888 BC_RGB888 BC_RGBA8888 BC_RGB161616 BC_RGBA16161616 BC_YUVA8888 BC_YUV422 BC_YUV420P BC_YUV422P BC_YUV444P BC_YUV411P BC_YUVJ420P BC_YUVJ422P BC_YUVJ444P BC_YUV422P16 BC_YUV444P16; do for j in BC_RGB565 BC_BGR565 BC_BGR888 BC_BGR8888 BC_RGB888 BC_RGBA8888 BC_RGB161616 BC_RGBA16161616 BC_YUVA8888 BC_YUV422 BC_YUV420P BC_YUV422P BC_YUV444P BC_YUV411P BC_YUVJ420P BC_YUVJ422P BC_YUVJ444P BC_YUV422P16 BC_YUV444P16; do echo $i"_to_"$j.png; gthumb $i"_to_"$j.png; done; done
@@ -777,8 +813,8 @@ int lqt_colormodel_has_conversion(int in_cmodel, int out_cmodel)
         case BC_YUVJ420P:     return 0; break;
         case BC_YUVJ422P:     return 0; break;
         case BC_YUVJ444P:     return 0; break;
-        case BC_YUV422P16:    return 0; break;
-        case BC_YUV444P16:    return 0; break;
+        case BC_YUV422P16:    return 1; break;
+        case BC_YUV444P16:    return 1; break;
         }
       break;
     case BC_RGBA16161616:
@@ -1020,7 +1056,7 @@ int lqt_colormodel_has_conversion(int in_cmodel, int out_cmodel)
         case BC_BGR8888:      return 0; break;
         case BC_RGB888:       return 1; break;
         case BC_RGBA8888:     return 0; break;
-        case BC_RGB161616:    return 0; break;
+        case BC_RGB161616:    return 1; break;
         case BC_RGBA16161616: return 0; break;
         case BC_YUVA8888:     return 0; break;
         case BC_YUV422:       return 0; break;
@@ -1043,7 +1079,7 @@ int lqt_colormodel_has_conversion(int in_cmodel, int out_cmodel)
         case BC_BGR8888:      return 0; break;
         case BC_RGB888:       return 1; break;
         case BC_RGBA8888:     return 0; break;
-        case BC_RGB161616:    return 0; break;
+        case BC_RGB161616:    return 1; break;
         case BC_RGBA16161616: return 0; break;
         case BC_YUVA8888:     return 0; break;
         case BC_YUV422:       return 0; break;
