@@ -1,7 +1,33 @@
-#include <string.h>
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ moov.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 #include <zlib.h>
+#include <stdlib.h>
+#include <string.h>
+
+#define LOG_DOMAIN "moov"
 
 int quicktime_moov_init(quicktime_moov_t *moov)
 {
@@ -29,14 +55,15 @@ int quicktime_moov_delete(quicktime_moov_t *moov)
 void quicktime_moov_dump(quicktime_moov_t *moov)
 {
 	int i;
-	printf("movie (moov)\n");
+	lqt_dump("movie (moov)\n");
 	quicktime_mvhd_dump(&(moov->mvhd));
 	quicktime_udta_dump(&(moov->udta));
         if(moov->has_iods)
           quicktime_iods_dump(&(moov->iods));
         for(i = 0; i < moov->total_tracks; i++)
 		quicktime_trak_dump(moov->trak[i]);
-	quicktime_ctab_dump(&(moov->ctab));
+        if(moov->has_ctab)
+          quicktime_ctab_dump(&(moov->ctab));
         
 }
 
@@ -72,13 +99,12 @@ static int read_cmov(quicktime_t *file,
                 if(quicktime_atom_is(&leaf_atom, "dcom"))
                 {
                         char data[5];
-//printf("read_cmov 1 %lld\n", quicktime_position(file));
                         quicktime_read_data(file, (uint8_t*)data, 4);
                         data[4] = 0;
                         if(strcmp(data, "zlib"))
                         {
-                                fprintf(stderr,
-                                        "read_cmov: compression '%c%c%c%c' not zlib.  Giving up and going to a movie.\n",
+                                lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN,
+                                        "read_cmov: compression '%c%c%c%c' not zlib.",
                                         data[0],
                                         data[1],
                                         data[2],
@@ -96,13 +122,6 @@ static int read_cmov(quicktime_t *file,
                         int uncompressed_size = quicktime_read_int32(file);
 /* Read compressed data */
                         int compressed_size = leaf_atom.end - quicktime_position(file);
-                        if(compressed_size > uncompressed_size)
-                        {
-                                fprintf(stderr,
-                                        "read_cmov: FYI compressed_size=%d uncompressed_size=%d\n",
-                                        compressed_size,
-                                        uncompressed_size);
-                        }
 
                         data_in = calloc(1, compressed_size);
                         quicktime_read_data(file, data_in, compressed_size);
@@ -177,17 +196,8 @@ int quicktime_read_moov(quicktime_t *file, quicktime_moov_t *moov, quicktime_ato
 
         do
         {
-//printf("quicktime_read_moov 1 %llx\n", quicktime_position(file));
                 quicktime_atom_read_header(file, &leaf_atom);
 
-/*
- * printf("quicktime_read_moov 2 %c%c%c%c\n",
- * leaf_atom.type[0],
- * leaf_atom.type[1],
- * leaf_atom.type[2],
- * leaf_atom.type[3]);
- */
-
                 if(quicktime_atom_is(&leaf_atom, "cmov"))
                 {
                         file->compressed_moov = 1;
@@ -209,30 +219,28 @@ int quicktime_read_moov(quicktime_t *file, quicktime_moov_t *moov, quicktime_ato
 		{
 			quicktime_trak_t *trak = quicktime_add_trak(file);
 			quicktime_read_trak(file, trak, &leaf_atom);
-/*printf("quicktime_read_moov trak\n"); */
 		}
 		else
 		if(quicktime_atom_is(&leaf_atom, "udta"))
 		{
-                //                        fprintf(stderr, "READ UDTA\n");
 			quicktime_read_udta(file, &(moov->udta), &leaf_atom);
 			quicktime_atom_skip(file, &leaf_atom);
 		}
 		else
 		if(quicktime_atom_is(&leaf_atom, "ctab"))
 		{
-			quicktime_read_ctab(file, &(moov->ctab));
-		}
+                quicktime_read_ctab(file, &(moov->ctab));
+                moov->has_ctab = 1;
+                }
 		else
 		if(quicktime_atom_is(&leaf_atom, "iods"))
 		{
-			quicktime_read_iods(file, &(moov->iods));
+                        quicktime_read_iods(file, &(moov->iods));
 			quicktime_atom_skip(file, &leaf_atom);
                         moov->has_iods = 1;
 		}
 		else
 		quicktime_atom_skip(file, &leaf_atom);
-//printf("quicktime_read_moov %llx %llx\n", quicktime_position(file), parent_atom->end);
 	}while(quicktime_position(file) < parent_atom->end);
 	
 	return 0;
@@ -241,27 +249,28 @@ int quicktime_read_moov(quicktime_t *file, quicktime_moov_t *moov, quicktime_ato
 void quicktime_finalize_moov(quicktime_t *file, quicktime_moov_t *moov)
   {
   int i;
-  long longest_duration = 0;
-  long duration, timescale;
+  int64_t longest_duration = 0;
+  int64_t duration;
+  int timescale;
   /* get the duration from the longest track in the mvhd's timescale */
   for(i = 0; i < moov->total_tracks; i++)
     {
-    quicktime_trak_fix_counts(file, moov->trak[i]);
+    quicktime_trak_fix_counts(file, moov->trak[i], moov->mvhd.time_scale);
     quicktime_trak_duration(moov->trak[i], &duration, &timescale);
     
-    duration = (long)((float)duration / timescale * moov->mvhd.time_scale);
+    duration = (long)((double)duration / timescale * moov->mvhd.time_scale + 0.5);
     
     if(duration > longest_duration)
       {
       longest_duration = duration;
       }
-
+    
     /* Add tracks to iods */
     quicktime_iods_add_track(&(moov->iods), moov->trak[i]);
-        
     }
   moov->mvhd.duration = longest_duration;
-  moov->mvhd.selection_duration = longest_duration;
+  if(!IS_MP4(file->file_type))
+    moov->mvhd.selection_duration = longest_duration;
   }
 
 void quicktime_write_moov(quicktime_t *file, quicktime_moov_t *moov)
@@ -284,11 +293,11 @@ void quicktime_write_moov(quicktime_t *file, quicktime_moov_t *moov)
         quicktime_write_mvhd(file, &(moov->mvhd));
         if(moov->has_iods)
           quicktime_write_iods(file, moov);
-	quicktime_write_udta(file, &(moov->udta));
 	for(i = 0; i < moov->total_tracks; i++)
-	{
-		quicktime_write_trak(file, moov->trak[i], moov->mvhd.time_scale);
-	}
+          {
+          quicktime_write_trak(file, moov->trak[i]);
+          }
+	quicktime_write_udta(file, &(moov->udta));
 	/*quicktime_write_ctab(file, &(moov->ctab)); */
 
 	quicktime_atom_write_footer(file, &atom);
