@@ -264,7 +264,7 @@ int quicktime_read_data(quicktime_t *file, uint8_t *data, int64_t size)
   return result;
   }
 
-int quicktime_write_data(quicktime_t *file, uint8_t *data, int size)
+int quicktime_write_data(quicktime_t *file, const uint8_t *data, int size)
   {
   int data_offset = 0;
   int writes_attempted = 0;
@@ -890,7 +890,7 @@ int quicktime_match_24(char *input, char *output)
 		return 0;
 }
 
-void do_hexdump(uint8_t * data, int len, int linebreak, FILE * f)
+static void do_hexdump(uint8_t * data, int len, int linebreak, FILE * f)
   {
   int i;
   int bytes_written = 0;
@@ -924,3 +924,16 @@ void lqt_hexdump_stdout(uint8_t * data, int len, int linebreak)
   {
   do_hexdump(data, len, linebreak, stdout);  
   }
+
+void lqt_dump_time(uint64_t t)
+  {
+  time_t ti;
+  struct tm tm;
+  /*  2082844800 = seconds between 1/1/04 and 1/1/70 */
+  ti = t - 2082844800;
+  localtime_r(&ti, &tm);
+  tm.tm_mon++;
+  printf("%04d-%02d-%02d %02d:%02d:%02d (%"PRId64")",
+         tm.tm_year+1900, tm.tm_mon, tm.tm_mday,
+         tm.tm_hour, tm.tm_min, tm.tm_sec, t);
+  }
