@@ -1,11 +1,35 @@
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ rechunk.c
 
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 #include <limits.h>
 #include <errno.h>
 
-int usage(void)
+static int usage(void)
 {
 	printf("usage: qtrechunk [-f framerate] [-w width] [-h height] [-c fourcc] [-b bitdepth] [-l file_list | <input frames>] <output movie>\n");
 	printf("	Concatenate input frames into a Quicktime movie.\n\n");
@@ -17,7 +41,7 @@ int usage(void)
 	return 0;
 }
 
-char ** add_frames_from_file(char ** input_frames,
+static char ** add_frames_from_file(char ** input_frames,
                              int * total_input_frames, char * list_filename)
   {
   FILE * input;
